<?php
require '../vendor/autoload.php'; // Include PHPSpreadsheet autoloader
include ('../settings/db/db.php'); // Database connection

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Style\Font;
use PhpOffice\PhpSpreadsheet\Style\NumberFormat;

// Get the date range from the GET parameters
$start_date = isset($_GET['d1']) ? $_GET['d1'] : '';
$end_date = isset($_GET['d2']) ? $_GET['d2'] : '';

if (!empty($start_date) && !empty($end_date)) {
    // Prepare SQL query to fetch sales data between selected dates
    $sql = "SELECT c.trade_name, c.generic_name, s.dateT, s.time, s.profit, s.transaction_id, s.invoiceNo, 
                   s.amount, s.cost_price, s.qty_sold, s.amount, s.entrant
            FROM medicine_list AS c 
            INNER JOIN sales_list AS s ON c.sno = s.sno
            WHERE STR_TO_DATE(s.dateT, '%m/%d/%Y') BETWEEN :start_date AND :end_date
            ORDER BY s.transaction_id DESC";

    $stmt = $dbo->prepare($sql);
    $stmt->bindValue(':start_date', $start_date);
    $stmt->bindValue(':end_date', $end_date);
    $stmt->execute();
    $result = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Initialize PHPSpreadsheet object
    $spreadsheet = new Spreadsheet();
    $sheet = $spreadsheet->getActiveSheet();

    // Set the header row for the Excel file
    $sheet->setCellValue('A1', 'Transaction Date and Time')
          ->setCellValue('B1', 'Dispenser')
          ->setCellValue('C1', 'Invoice No.')
          ->setCellValue('D1', 'Trade Name')
          ->setCellValue('E1', 'Quantity Sold')
          ->setCellValue('F1', 'Amount')
          ->setCellValue('G1', 'Profit');

    // Set the first row as bold
    $sheet->getStyle('A1:G1')->getFont()->setBold(true);

  
    // Set default font for the entire sheet
    $spreadsheet->getDefaultStyle()->getFont()->setName('Times New Roman');
    // Initialize the row count
    $rowCount = 2; // Start from row 2, as row 1 is for headers

    // Set column widths
    $sheet->getColumnDimension('A')->setWidth(25);
    $sheet->getColumnDimension('B')->setWidth(15);
    $sheet->getColumnDimension('C')->setWidth(15);
    $sheet->getColumnDimension('D')->setWidth(25);
    $sheet->getColumnDimension('E')->setWidth(15);
    $sheet->getColumnDimension('F')->setWidth(15);
    $sheet->getColumnDimension('G')->setWidth(15);

    // Loop through the result and populate the spreadsheet
    foreach ($result as $row) {
        $amount = !empty($row['amount']) ? (float)$row['amount'] : 0.0; // Ensure amount is a float
        $profit = !empty($row['profit']) ? (float)$row['profit'] : 0.0; // Ensure profit is a float

        $sheet->setCellValue('A' . $rowCount, $row['dateT'] . ', ' . $row['time'])
              ->setCellValue('B' . $rowCount, $row['entrant'])
              ->setCellValue('C' . $rowCount, $row['invoiceNo'])
              ->setCellValue('D' . $rowCount, $row['trade_name'])
              ->setCellValue('E' . $rowCount, $row['qty_sold'])
              ->setCellValue('F' . $rowCount, number_format($amount, 2))
              ->setCellValue('G' . $rowCount, number_format($profit, 2));
        $rowCount++;
    }
    // Set the filename and output the Excel file for download
    $filename = "Sales_Report_" . $start_date . "_to_" . $end_date . ".xlsx";
    header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
    header('Content-Disposition: attachment; filename="' . $filename . '"');
    header('Cache-Control: max-age=0');

    $writer = new Xlsx($spreadsheet);
    $writer->save('php://output');
    exit;
} else {
    echo "Please provide a valid date range.";
}
?>
WORKING