<?php
require '../vendor/autoload.php'; // Include PHPSpreadsheet autoloader
include ('../settings/db/db.php'); // Database connection

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Style\NumberFormat;

// Fetch users from the users table
try {
    $user_stmt = $dbo->query("SELECT uid, userid FROM users");
    $users = $user_stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    echo "Error fetching users: " . $e->getMessage();
}

// Fetch the 'd1', 'd2', and 'userid' from GET request
$start_date = $_GET['d1'] ?? '';
$end_date = $_GET['d2'] ?? '';
$user_id = $_GET['userid'] ?? '';

if (!empty($start_date) && !empty($end_date)) {
    // Prepare the SQL query
    $sql = "SELECT c.trade_name, s.entrant, c.generic_name, s.dateT, s.time, s.profit, 
                   s.transaction_id, s.invoiceNo, s.amount, s.cost_price, s.qty_sold
            FROM medicine_list AS c
            INNER JOIN sales_list AS s ON c.sno = s.sno
            WHERE STR_TO_DATE(s.dateT, '%m/%d/%Y') BETWEEN :start_date AND :end_date";

    // Add user filter if applicable
    if (!empty($user_id)) {
        $sql .= " AND s.entrant = :userid";
    }

    $sql .= " ORDER BY s.transaction_id DESC";

    try {
        $stmt = $dbo->prepare($sql);
        $stmt->bindValue(':start_date', $start_date);
        $stmt->bindValue(':end_date', $end_date);

        if (!empty($user_id)) {
            $stmt->bindValue(':userid', $user_id);
        }

        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        echo "Error fetching sales report: " . $e->getMessage();
    }

    // Initialize PHPSpreadsheet object
    $spreadsheet = new Spreadsheet();
    $sheet = $spreadsheet->getActiveSheet();

    // Set the header row for the Excel file
    $sheet->setCellValue('A1', 'Transaction Date and Time')
          ->setCellValue('B1', 'Dispenser')
          ->setCellValue('C1', 'Invoice No.')
          ->setCellValue('D1', 'Trade Name')
        //->setCellValue('E1', 'Generic Name')
          ->setCellValue('E1', 'Qty Sold')
          ->setCellValue('F1', 'Amount')
          ->setCellValue('G1', 'Profit');

    // Initialize the row count
    $rowCount = 2; // Start from row 2, as row 1 is for headers

    // Set column widths
    $sheet->getColumnDimension('A')->setWidth(25);
    $sheet->getColumnDimension('B')->setWidth(12);
    $sheet->getColumnDimension('C')->setWidth(10);
    $sheet->getColumnDimension('D')->setWidth(30);
    //$sheet->getColumnDimension('E')->setWidth(20);
    $sheet->getColumnDimension('E')->setWidth(10);
    $sheet->getColumnDimension('F')->setWidth(12);
    $sheet->getColumnDimension('G')->setWidth(12);

    // Loop through the result and populate the spreadsheet
    foreach ($result as $row) {
        $amount = !empty($row['amount']) ? (float)$row['amount'] : 0.0; // Ensure amount is a float
        $profit = !empty($row['profit']) ? (float)$row['profit'] : 0.0; // Ensure profit is a float

        // Directly set the float values for amount and profit
        $sheet->setCellValue('A' . $rowCount, $row['dateT'] . ', ' . $row['time'])
              ->setCellValue('B' . $rowCount, $row['entrant'])
              ->setCellValue('C' . $rowCount, $row['invoiceNo'])
              ->setCellValue('D' . $rowCount, $row['trade_name'])
              //->setCellValue('E' . $rowCount, $row['generic_name'])
              ->setCellValue('E' . $rowCount, $row['qty_sold'])
              ->setCellValue('F' . $rowCount, $amount) // Directly set the float value
              ->setCellValue('G' . $rowCount, $profit); // Directly set the float value
        $rowCount++;
    }

    // Format amount and profit as numbers
    $sheet->getStyle('F2:F' . ($rowCount - 1))->getNumberFormat()->setFormatCode(NumberFormat::FORMAT_NUMBER_00);
    $sheet->getStyle('G2:G' . ($rowCount - 1))->getNumberFormat()->setFormatCode(NumberFormat::FORMAT_NUMBER_00);

    // Set the first row as bold
    $sheet->getStyle('A1:G1')->getFont()->setBold(true);

    // Set default font for the entire sheet
    $spreadsheet->getDefaultStyle()->getFont()->setName('Times New Roman');

    // Set the filename and output the Excel file for download
    $filename = "Sales_Report_" . $start_date . "_to_" . $end_date . ".xlsx";
    header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
    header('Content-Disposition: attachment; filename="' . $filename . '"');
    header('Cache-Control: max-age=0');

    $writer = new Xlsx($spreadsheet);
    $writer->save('php://output');
    exit;
} else {
    echo "Please provide a valid date range.";
}
?>
