<?php
include "../settings/db/db.php";

// Fetch all accounts to populate the dropdown
$accounts_query = "SELECT acc_id, acc_name FROM accounts_tbl";
$accounts_result = $con->query($accounts_query);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Account Ledger</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
</head>
<body>

<div class="container mt-5">
    <h2>Select Account</h2>
    <form method="GET" action="" id="accountForm">
        <div class="form-group">
            <label for="acc_id">Account:</label>
            <select class="form-control" id="acc_id" name="acc_id" onchange="this.form.submit()">
                <option value="">Select an account</option>
                <?php while ($account = $accounts_result->fetch_assoc()): ?>
                    <option value="<?php echo $account['acc_id']; ?>"><?php echo htmlspecialchars($account['acc_name']); ?></option>
                <?php endwhile; ?>
            </select>
        </div>
    </form>

    <?php
    if (isset($_GET['acc_id']) && !empty($_GET['acc_id'])) {
        $account_id = $_GET['acc_id'];
        
        // Fetch the selected account name
        $account_query = $con->prepare("SELECT acc_name FROM accounts_tbl WHERE acc_id = ?");
        $account_query->bind_param("i", $account_id);
        $account_query->execute();
        $account_result = $account_query->get_result();
        
        if ($account_result->num_rows > 0) {
            $account = $account_result->fetch_assoc();
            $account_name = htmlspecialchars($account['acc_name']);
            
            // Fetch the ledger entries for the selected account
            $query = "
            (SELECT 
                j.journal_date, 
                j.journal_no, 
                j.journal_memo,
                'debit' AS entry_type, 
                d.debit_amount AS amount, 
                NULL AS credit_amount
            FROM 
                journal j
            LEFT JOIN 
                debit_journal d ON j.journal_no = d.journal_no
            WHERE 
                d.debit_acc_id = ?
            )
            UNION ALL
            (SELECT 
                j.journal_date, 
                j.journal_no, 
                j.journal_memo,
                'credit' AS entry_type, 
                NULL AS debit_amount, 
                c.credit_amount AS amount
            FROM 
                journal j
            LEFT JOIN 
                credit_journal c ON j.journal_no = c.journal_no
            WHERE 
                c.credit_acc_id = ?
            )
            ORDER BY 
                journal_date, journal_no, entry_type DESC";

            $stmt = $con->prepare($query);
            $stmt->bind_param("ii", $account_id, $account_id);
            $stmt->execute();
            $ledger_entries = $stmt->get_result();

            $balance = 0;
            $debit_total = 0;
            $credit_total = 0;
            ?>
            <h2>Ledger for Account: <?php echo $account_name; ?></h2>
            <table class="table table-bordered table-striped text-nowrap">
                <thead style="background-color: #004d40; border-color: #004d40; color: white; line-height: 0;">
                    <tr>
                        <th style="text-align:center;width:10%;">Date</th>
                        <th style="text-align:center;width:20%;">Journal No</th>
                        <th style="text-align:center;width:15%;">Description</th>
                        <th style="text-align:center;width:15%;">Debit</th>
                        <th style="text-align:center;width:15%;">Credit</th>
                        <th style="text-align:center;width:15%;">Balance</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    while ($entry = $ledger_entries->fetch_assoc()):
                        $debit_amount = $entry['entry_type'] == 'debit' ? $entry['amount'] : 0;
                        $credit_amount = $entry['entry_type'] == 'credit' ? $entry['amount'] : 0;
                        $debit_total += $debit_amount;
                        $credit_total += $credit_amount;
                        $balance += $debit_amount - $credit_amount;
                    ?>
                    <tr>
                        <td style="text-align:center;"><?php echo htmlspecialchars($entry['journal_date']); ?></td>
                        <td style="text-align:center;"><?php echo htmlspecialchars($entry['journal_no']); ?></td>
                        <td style="text-align:center;"><?php echo htmlspecialchars($entry['journal_memo']); ?></td>
                        <td style="text-align:right;"><?php echo number_format($debit_amount, 2); ?></td>
                        <td style="text-align:right;"><?php echo number_format($credit_amount, 2); ?></td>
                        <td style="text-align:right;"><?php echo number_format($balance, 2); ?></td>
                    </tr>
                    <?php endwhile; ?>
                    <tr>
                        <td colspan="3" style="text-align:right;"><strong>Totals</strong></td>
                        <td style="text-align:right;"><strong><?php echo number_format($debit_total, 2); ?></strong></td>
                        <td style="text-align:right;"><strong><?php echo number_format($credit_total, 2); ?></strong></td>
                        <td style="text-align:right;"><strong><?php echo number_format($balance, 2); ?></strong></td>
                    </tr>
                </tbody>
            </table>
            <?php
        } else {
            echo "<p>Account not found.</p>";
        }
    }
    ?>
</div>

</body>
</html>
