<?php
require '../vendor/autoload.php'; // Include Composer autoloader
include ('../settings/db/db.php'); // Database connection and company name

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Pdf\Tcpdf; // Import TCPDF writer
use PhpOffice\PhpSpreadsheet\Style\NumberFormat;

$start_date = isset($_GET['d1']) ? htmlspecialchars($_GET['d1']) : '';
$end_date = isset($_GET['d2']) ? htmlspecialchars($_GET['d2']) : '';

if (!empty($start_date) && !empty($end_date)) {
    // SQL query to fetch sales data
    $sql = "SELECT c.trade_name, c.generic_name, s.dateT, s.time, s.profit, s.transaction_id, s.invoiceNo, 
                   s.amount, s.cost_price, s.qty_sold, s.entrant
            FROM medicine_list AS c 
            INNER JOIN sales_list AS s ON c.sno = s.sno
            WHERE STR_TO_DATE(s.dateT, '%m/%d/%Y') BETWEEN :start_date AND :end_date
            ORDER BY s.transaction_id DESC";

    try {
        $stmt = $dbo->prepare($sql);
        $stmt->bindValue(':start_date', $start_date);
        $stmt->bindValue(':end_date', $end_date);
        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (Exception $e) {
        echo "Error fetching data: " . $e->getMessage();
        exit;
    }

    // Initialize TCPDF object
    $pdf = new \TCPDF();

    // Disable the header line
    $pdf->setPrintHeader(false);

    // Set document metadata
    $pdf->SetCreator(PDF_CREATOR);
    $pdf->SetAuthor($name); // Set company name as the author
    $pdf->SetTitle('Sales Report');
    $pdf->SetSubject('Sales Report from ' . $start_date . ' to ' . $end_date);
    $pdf->SetKeywords('TCPDF, PDF, sales, report');

 // Add a page
$pdf->AddPage();

// Add logo
$logoPath = '../settings/uploads/' . $logo; // Corrected logo file path
$pdf->Image($logoPath, 10, 10, 30, 0, 'PNG', '', '', false, 300, '', false, false, 0, false, false, false); // Adjust width as needed

// Move to the right of the logo
$pdf->SetX(50); // Adjust the X position to start writing after the logo

// Set font for header text
$pdf->SetFont('times', 'B', 40); // Bold font for header
// Bold font for header// Center the title manually
$titleWidth = $pdf->GetStringWidth('Sales Report');
$pdf->SetX((210 - $titleWidth) / 2); // 210 is the width of the A4 page in mm
$pdf->Cell($titleWidth, 10, 'Sales Report', 0, 1, 'C'); // Title

$pdf->SetFont('times', '', 20); // Normal font for subheader
$pdf->Cell(0, 10, $name, 0, 1, 'C'); // Company name (centered)
$pdf->Cell(0, 10, 'Reported by: ' . htmlspecialchars($_SESSION['userid']), 0, 1, 'C'); // User ID (centered)
$pdf->Cell(0, 10, 'From ' . $start_date . ' to ' . $end_date, 0, 1, 'C'); // Date range (centered)

// Add space before the table
$pdf->Ln(5);


    // Set font for the table
    $pdf->SetFont('times', '', 12);

    // Create table header
    $html = '<table border="1" cellpadding="4" width="100%">
                <thead>
                    <tr>
                        <th width="13%" align="center">Date</th>
                        <th width="15%" align="center">Dispenser</th>
                        <th width="13%" align="center">Invoice No.</th>
                        <th width="32%" align="center">Trade Name</th>
                        <th width="7%" align="center">Qty</th>
                        <th width="10%" align="center">Amount</th>
                        <th width="10%" align="center">Profit</th>
                    </tr>
                </thead>
                <tbody>';

    $totalAmount = 0;
    $totalProfit = 0;

    foreach ($result as $row) {
        $amount = !empty($row['amount']) ? (float)$row['amount'] : 0.0;
        $profit = !empty($row['profit']) ? (float)$row['profit'] : 0.0;

        $html .= '<tr>
                    <td width="13%">' . htmlspecialchars($row['dateT']) . '</td>
                    <td width="15%">' . htmlspecialchars($row['entrant']) . '</td>
                    <td width="13%">' . htmlspecialchars($row['invoiceNo']) . '</td>
                    <td width="32%">' . htmlspecialchars($row['trade_name']) . '</td>
                    <td width="7%" align="center">' . htmlspecialchars($row['qty_sold']) . '</td>
                    <td width="10%" align="right">' . number_format($amount, 2) . '</td>
                    <td width="10%" align="right">' . number_format($profit, 2) . '</td>
                  </tr>';
                  
        $totalAmount += $amount;
        $totalProfit += $profit;
    }

    // Add summary row
    $html .= '<tr>
                <td colspan="5" align="right"><strong>Total</strong></td>
                <td align="right"><strong>' . number_format($totalAmount, 2) . '</strong></td>
                <td align="right"><strong>' . number_format($totalProfit, 2) . '</strong></td>
              </tr>';

    $html .= '</tbody></table>';

    // Output the HTML content
    $pdf->writeHTML($html, true, false, true, false, '');

    // Set the filename
    $filename = "Sales_Report_" . $start_date . "_to_" . $end_date . ".pdf";

    // Output the PDF
    $pdf->Output($filename, 'D');

    exit;

} else {
    echo "Please provide a valid date range.";
}
?>
