<?php
require_once('../vendor/autoload.php'); // Adjust the path as needed

include('../settings/db/db.php');  // Database connection details

// Fetch invoice number from URL with input validation
$invoice = filter_input(INPUT_GET, 'invoiceNo', FILTER_SANITIZE_STRING);

// Prepare and execute the query with error handling
$result = $dbo->prepare("SELECT * FROM sales_list WHERE invoiceNo = :invoiceNo");
$result->bindParam(':invoiceNo', $invoice);

if (!$result->execute()) {
    die("Error fetching sales data: " . implode(", ", $result->errorInfo()));
}

$saleData = $result->fetch(PDO::FETCH_ASSOC);

if (!$saleData) {
    die("No sale data found for the specified invoice number.");
}

$entrant = $saleData['entrant'];

// Initialize customer variables
$customer = null;

// Check if customer_id exists in saleData
if (isset($saleData['customer_id'])) {
    $customer_id = $saleData['customer_id'];

    // Fetch customer details if customer_id exists
    $customerResult = $dbo->prepare("SELECT * FROM customer WHERE id = :id");
    $customerResult->bindParam(':id', $customer_id);
    $customerResult->execute();
    $customer = $customerResult->fetch(PDO::FETCH_ASSOC);
}

// Create new PDF document
$pdf = new TCPDF('P', 'mm', 'A4', true, 'UTF-8', false);
$pdf->SetCreator(PDF_CREATOR);
$pdf->SetAuthor('Your Company Name');
$pdf->SetTitle('Invoice');

// Set margins
$pdf->SetMargins(10, 10, 10); // Left, Top, Right
$pdf->SetAutoPageBreak(TRUE, 10); // Auto page break with bottom margin

$pdf->AddPage();

// Set font to Times New Roman
$pdf->SetFont('times', 'B', 16);
$pdf->Cell(0, 10, 'Invoice', 0, 1, 'C');
$pdf->Ln(5);

// Customer Details (only if available)
if ($customer) {
    $pdf->SetFont('times', '', 12);
    $pdf->Cell(0, 10, 'Customer Name: ' . htmlspecialchars($customer['name']), 0, 1);
    $pdf->Cell(0, 10, 'Address: ' . htmlspecialchars($customer['address']), 0, 1);
    $pdf->Cell(0, 10, 'Phone: ' . htmlspecialchars($customer['phone']), 0, 1);
    $pdf->Cell(0, 10, 'Email: ' . htmlspecialchars($customer['email']), 0, 1);
    $pdf->Ln(5);
}

// Invoice Information
$pdf->Cell(0, 10, 'Receipt No: ' . htmlspecialchars($saleData['invoiceNo']), 0, 1);
$pdf->Cell(0, 10, 'Date: ' . date("F j, Y, g:i a"), 0, 1);
$pdf->Cell(0, 10, 'Prepared By: ' . htmlspecialchars($entrant), 0, 1);
$pdf->Ln(5);

// Product Table Header
$pdf->SetFont('times', 'B', 12);
$pdf->Cell(15, 10, 'No', 1);
$pdf->Cell(85, 10, 'Product Name', 1);
$pdf->Cell(25, 10, 'Qty', 1);
$pdf->Cell(25, 10, 'Rate', 1);
$pdf->Cell(25, 10, 'Amount', 1);
$pdf->Ln();

$pdf->SetFont('times', '', 12);
$n = 1;
$totalAmount = 0; // Initialize total amount variable

$salesResult = $dbo->prepare("SELECT trade_name, sell_price, (sell_price * qty_sold) AS amount, qty_sold FROM sales_list WHERE invoiceNo = :invoiceNo");
$salesResult->bindParam(':invoiceNo', $invoice);
$salesResult->execute();

while ($row = $salesResult->fetch(PDO::FETCH_ASSOC)) {
    $pdf->Cell(15, 10, $n++, 1);
    $pdf->Cell(85, 10, htmlspecialchars($row['trade_name']), 1);
    $pdf->Cell(25, 10, htmlspecialchars($row['qty_sold']), 1);
    $pdf->Cell(25, 10, number_format($row['sell_price'], 2), 1);
    $pdf->Cell(25, 10, number_format($row['amount'], 2), 1);
    $pdf->Ln();

    // Add to total amount
    $totalAmount += $row['amount']; // Update total amount
}

// Total Amount - In the second-to-last and last columns
$pdf->SetFont('times', 'B', 12);
$pdf->Cell(15, 10, '', 0); // Empty cell for alignment

$pdf->Cell(25, 10, '', 0); // Empty cell for Qty column
$pdf->Cell(85, 10, '', 0); // Empty cell for Rate column
$pdf->Cell(25, 10, 'Total:', 1);
$pdf->Cell(25, 10, number_format($totalAmount, 2), 1, 1, 'C'); // Center the total amount in the last column

// Output the PDF document
$pdf->Output('invoice_' . $invoice . '.pdf', 'I');










//JUST ADDEED

//set font to arial, bold, 14pt
$pdf->SetFont('Arial','B',14);

//Cell(width , height , text , border , end line , [align] )

$pdf->Cell(130 ,5,'GEMUL APPLIANCES.CO',0,0);
$pdf->Cell(59 ,5,'INVOICE',0,1);//end of line

//set font to arial, regular, 12pt
$pdf->SetFont('Arial','',12);

$pdf->Cell(130 ,5,'[Street Address]',0,0);
$pdf->Cell(59 ,5,'',0,1);//end of line

$pdf->Cell(130 ,5,'[City, Country, ZIP]',0,0);
$pdf->Cell(25 ,5,'Date',0,0);
$pdf->Cell(34 ,5,'[dd/mm/yyyy]',0,1);//end of line

$pdf->Cell(130 ,5,'Phone [+12345678]',0,0);
$pdf->Cell(25 ,5,'Invoice #',0,0);
$pdf->Cell(34 ,5,'[1234567]',0,1);//end of line

$pdf->Cell(130 ,5,'Fax [+12345678]',0,0);
$pdf->Cell(25 ,5,'Customer ID',0,0);
$pdf->Cell(34 ,5,'[1234567]',0,1);//end of line

//make a dummy empty cell as a vertical spacer
$pdf->Cell(189 ,10,'',0,1);//end of line

//billing address
$pdf->Cell(100 ,5,'Bill to',0,1);//end of line

//add dummy cell at beginning of each line for indentation
$pdf->Cell(10 ,5,'',0,0);
$pdf->Cell(90 ,5,'[Name]',0,1);

$pdf->Cell(10 ,5,'',0,0);
$pdf->Cell(90 ,5,'[Company Name]',0,1);

$pdf->Cell(10 ,5,'',0,0);
$pdf->Cell(90 ,5,'[Address]',0,1);

$pdf->Cell(10 ,5,'',0,0);
$pdf->Cell(90 ,5,'[Phone]',0,1);

//make a dummy empty cell as a vertical spacer
$pdf->Cell(189 ,10,'',0,1);//end of line

//invoice contents
$pdf->SetFont('Arial','B',12);

$pdf->Cell(130 ,5,'Description',1,0);
$pdf->Cell(25 ,5,'Taxable',1,0);
$pdf->Cell(34 ,5,'Amount',1,1);//end of line

$pdf->SetFont('Arial','',12);

//Numbers are right-aligned so we give 'R' after new line parameter

$pdf->Cell(130 ,5,'UltraCool Fridge',1,0);
$pdf->Cell(25 ,5,'-',1,0);
$pdf->Cell(34 ,5,'3,250',1,1,'R');//end of line

$pdf->Cell(130 ,5,'Supaclean Diswasher',1,0);
$pdf->Cell(25 ,5,'-',1,0);
$pdf->Cell(34 ,5,'1,200',1,1,'R');//end of line

$pdf->Cell(130 ,5,'Something Else',1,0);
$pdf->Cell(25 ,5,'-',1,0);
$pdf->Cell(34 ,5,'1,000',1,1,'R');//end of line

//summary
$pdf->Cell(130 ,5,'',0,0);
$pdf->Cell(25 ,5,'Subtotal',0,0);
$pdf->Cell(4 ,5,'$',1,0);
$pdf->Cell(30 ,5,'4,450',1,1,'R');//end of line

$pdf->Cell(130 ,5,'',0,0);
$pdf->Cell(25 ,5,'Taxable',0,0);
$pdf->Cell(4 ,5,'$',1,0);
$pdf->Cell(30 ,5,'0',1,1,'R');//end of line

$pdf->Cell(130 ,5,'',0,0);
$pdf->Cell(25 ,5,'Tax Rate',0,0);
$pdf->Cell(4 ,5,'$',1,0);
$pdf->Cell(30 ,5,'10%',1,1,'R');//end of line

$pdf->Cell(130 ,5,'',0,0);
$pdf->Cell(25 ,5,'Total Due',0,0);
$pdf->Cell(4 ,5,'$',1,0);
$pdf->Cell(30 ,5,'4,450',1,1,'R');//end of line

?>
