<?php
require_once('../vendor/autoload.php'); // Adjust the path as needed
include('../settings/db/db.php');  // Database connection details

// Fetch invoice number from URL with input validation
$invoice = filter_input(INPUT_GET, 'invoiceNo', FILTER_SANITIZE_STRING); // Ensure this matches the JS code

if (!$invoice) {
    die("No invoice number provided.");
}

// Prepare and execute the query with error handling
$result = $dbo->prepare("SELECT * FROM sales_list WHERE invoiceNo = :invoiceNo");
$result->bindParam(':invoiceNo', $invoice);

if (!$result->execute()) {
    die("Error fetching data: " . implode(", ", $result->errorInfo()));
}

$saleData = $result->fetch(PDO::FETCH_ASSOC);
$amount = $saleData['amount'];
$entrant = $saleData['entrant'];


$saleData = $result->fetch(PDO::FETCH_ASSOC);
$amount = $saleData['amount'];
$entrant = $saleData['entrant'];

// Barcode generation
use BarcodeBakery\Barcode\BCGcode128;
use BarcodeBakery\Common\BCGColor;
use BarcodeBakery\Common\BCGDrawing;

$colorBlack = new BCGColor(0, 0, 0);
$colorWhite = new BCGColor(255, 255, 255);

$code = new BCGcode128();
$code->setScale(2);
$code->setThickness(30);
$code->setForegroundColor($colorBlack);
$code->setBackgroundColor($colorWhite);
$code->setFont(0); // No font for no label
$code->parse($invoice);

// Pass the barcode object ($code) to BCGDrawing instead of an empty string
$drawing = new BCGDrawing($code, $colorWhite);
$drawing->setDPI(72);
ob_start();
$drawing->finish(BCGDrawing::IMG_FORMAT_PNG);
$barcodeImage = base64_encode(ob_get_contents());
ob_end_clean();

?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title><?php include_once('../settings/inc/title/title.php'); ?> | Dashboard</title>
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no">
    
    <!-- Stylesheets -->
    <link rel="stylesheet" href="../settings/setup/plugins/fontawesome-free/css/all.min.css">
    <link rel="stylesheet" href="../settings/setup/plugins/ionicons/css/ionicons.min.css">
    <link rel="stylesheet" href="../settings/setup/plugins/tempusdominus-bootstrap-4/css/tempusdominus-bootstrap-4.min.css">
    <link rel="stylesheet" href="../settings/setup/plugins/icheck-bootstrap/icheck-bootstrap.min.css">
    <link rel="stylesheet" href="../settings/setup/plugins/jqvmap/jqvmap.min.css">
    <link rel="stylesheet" href="../settings/setup/dist/css/adminlte.min.css">
    <link rel="stylesheet" href="../settings/setup/bootstrap/css/simplebootstrap.css">
    <link rel="stylesheet" href="../settings/setup/plugins/overlayScrollbars/css/OverlayScrollbars.min.css">
    <link rel="stylesheet" href="../settings/setup/plugins/datatables-bs4/css/dataTables.bootstrap4.min.css">
    <link rel="stylesheet" href="../settings/setup/plugins/datatables-responsive/css/responsive.bootstrap4.min.css">
    <link rel="stylesheet" href="../settings/setup/plugins/datatables-buttons/css/buttons.bootstrap4.min.css">

    <link rel="stylesheet" href="../settings/setup/bootstrap/css/simplebootstrap.css"> 
    <style>
        body {
            font-family: "Times New Roman", Times, serif;
            font-size: 18px;
        }
        #printable { display: none; }
        @media print {
            #non-printable { display: none; }
            #printable { display: block; }
        }
    </style>
    
    <script>
        function printDiv(divName) { 
            const printContents = document.getElementById(divName).innerHTML; 
            const originalContents = document.body.innerHTML; 
            document.body.innerHTML = printContents; 
            window.print(); 
            document.body.innerHTML = originalContents; 
        }
    </script>
</head>
<body class="hold-transition sidebar-mini layout-fixed layout-footer-fixed layout-navbar-fixed sidebar-collapse">
<div class="wrapper">

    <?php include_once "../settings/inc/nav.php"; ?>

    <!-- Content Wrapper -->
    <div class="content-wrapper" style="background-color: #2F4F4F; color: white; ">
        <!-- Content Header -->
        <div class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1 class="m-0">Receipt <small>Preview</small></h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="#">Home</a></li>
                            <li class="breadcrumb-item active">Receipt</li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>

        <section class="content" style="background-color: #2F4F4F; color: white;">

            <div class="container-fluid" style="background-color: #2F4F4F; color: white; ">
                <!-- General form elements -->
                <div class="card card-outline">
                    <!-- Card Header -->
                    <div class="card-header with-border" style="background-color: #0d47a1; color: white; padding: 4px;">
                        <h3 class="card-title">Receipt Details</h3>
                    </div>
                    <!-- Card Body -->
                    <div class="card-body" style="background-color: #c1ab86; color: black; padding: 4px;">
                        <div class="col-xs-4">
                            <div class="container">
                                <a href="pos.php">
                                    <button class="btn btn-success addmore" style="background-color: #004d40; border-color: #004d40; line-height: 0.6;">
                                        Back to Sales
                                    </button>
                                </a>

                                <div id="printableArea" style="font: bold 13px 'Times'; width: 270px;">
                                    <div style="font: bold 13px 'Times'; float: center;">
                                        <div style="font: bold 22px 'Times';"><?php echo htmlspecialchars($name); ?><br></div>
                                        <div style="font: bold 18px 'Times'; padding-left: 80px;">Sales Receipt</div>
                                        <?php echo nl2br(htmlspecialchars($address)); ?><br>
                                        <?php echo nl2br(htmlspecialchars($address2)); ?><br>
                                        Contacts: <?php echo htmlspecialchars($phone); ?><br>
                                        E-mail: <?php echo htmlspecialchars($email); ?>
                                    </div>

                                    <div style="font: bold 12px 'Times';">
                                        <table>
                                            <tr>
                                                <td>Receipt No:</td>
                                                <td><span id="invoiceNoSpan"></span></td>
                                            </tr>
                                            <tr>
                                                <td>Date:</td>
                                                <td><?php echo date("F j, Y, g:i a"); ?></td>
                                            </tr>
                                            <tr>
                                                <td>Prepared By:</td>
                                                <td><?php echo htmlspecialchars($entrant); ?></td>
                                            </tr>
                                            <tr>
                                                <td>Served By:</td>
                                                <td><?php echo htmlspecialchars($_SESSION['userid']); ?></td>
                                            </tr>
                                        </table>
                                        
                                        <table border="2" width="250px;">
                                            <thead>
                                                <tr>
                                                    <th>No</th>
                                                    <th style="text-align: center;">Name</th>
                                                    <th style="text-align: center;">Qty</th>
                                                    <th style="text-align: center;">Rate@</th>
                                                    <th style="text-align: center;">Amount</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php
                                                $n = 1;
                                                $salesResult = mysqli_query($con, "SELECT trade_name, sell_price, (sell_price * qty_sold) AS amount, qty_sold FROM sales_list WHERE invoiceNo='$invoice'") or die(mysqli_error($con));
                                                while ($row = mysqli_fetch_array($salesResult)) {
                                                ?>
                                                <tr>
                                                    <td><?php echo $n++; ?></td>
                                                    <td style="text-align: left;"><?php echo htmlspecialchars($row['trade_name']); ?></td>
                                                    <td style="text-align: center;"><?php echo htmlspecialchars($row['qty_sold']); ?></td>
                                                    <td style="text-align: center;"><?php echo number_format($row['sell_price'], 2); ?></td>
                                                    <td style="text-align: right; padding-right: 5px;"><?php echo number_format($row['amount'], 2); ?></td>
                                                </tr>
                                                <?php
                                                }
                                                ?>
                                                <tr>
                                                    <td colspan="4" style="text-align: right;">Total: <strong>&nbsp;<?php echo htmlspecialchars($currency); ?></strong></td>
                                                    <td colspan="3" style="text-align: right; padding-right: 5px;">
                                                        <?php
                                                        $resultTotal = $dbo->prepare("SELECT SUM(amount) AS amt FROM sales_list WHERE invoiceNo = :invoiceNo");
                                                        $resultTotal->bindParam(':invoiceNo', $invoice);
                                                        $resultTotal->execute();
                                                        $totalRow = $resultTotal->fetch(PDO::FETCH_ASSOC);
                                                        echo number_format($totalRow['amt'], 2);
                                                        ?>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                        <img src="data:image/png;base64,<?php echo $barcodeImage; ?>" alt="Barcode" style="display:block;padding-left:30px;padding-top:10px;">
                                       
                                        <p style="padding-left: 30px; padding-top: 10px;"><?php echo htmlspecialchars($tagline); ?></p>
                                    </div>
                                </div>
                                <input type="button" class="btn btn-info" onclick="printDiv('printableArea')" style="background-color: #0d47a1; border-color: #0d47a1; line-height: 0.6;" value='Print'/>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </div>

    <?php include("../settings/inc/title/footer.php"); ?>
</div>

<!-- Scripts -->
<script src="../settings/setup/plugins/jquery/jquery.min.js"></script>
<script src="../settings/setup/plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
<script src="../settings/setup/plugins/overlayScrollbars/js/jquery.overlayScrollbars.min.js"></script>
<script src="../settings/setup/dist/js/adminlte.js"></script>
<script src="../settings/setup/plugins/datatables/jquery.dataTables.min.js"></script>
<script src="../settings/setup/plugins/datatables-bs4/js/dataTables.bootstrap4.min.js"></script>
<script src="../settings/setup/plugins/datatables-responsive/js/dataTables.responsive.min.js"></script>
<script src="../settings/setup/plugins/datatables-responsive/js/responsive.bootstrap4.min.js"></script>
<script src="../settings/setup/plugins/datatables-buttons/js/dataTables.buttons.min.js"></script>
<script src="../settings/setup/plugins/datatables-buttons/js/buttons.bootstrap4.min.js"></script>

<script>
document.addEventListener('DOMContentLoaded', () => {
    const invoiceNoSpan = document.getElementById('invoiceNoSpan');

    // Extract invoiceNo from URL
    const urlParams = new URLSearchParams(window.location.search);
    const invoiceNo = urlParams.get('invoiceNo'); // Ensure this matches the PHP code
    if (invoiceNo) {
        invoiceNoSpan.textContent = invoiceNo;
    }
});
</script>
</body>
</html>
